==> pythonmagick_0.7.orig.tar.gz: PythonMagick-0.7/pythonmagick_src/_Geometry.cpp <==

// Boost Includes ==============================================================
#include <boost/python.hpp>
#include <boost/cstdint.hpp>

// Includes ====================================================================
#include <Magick++/Geometry.h>

// Using =======================================================================
using namespace boost::python;

// Module ======================================================================
void Export_pyste_src_Geometry()
{
    class_< Magick::Geometry >("Geometry", init<  >())
        .def(init< unsigned int, unsigned int, optional< unsigned int, unsigned int, bool, bool > >())
        .def(init< const std::string& >())
        .def(init< const char* >())
        .def(init< const Magick::Geometry& >())
        .def(init< const MagickLib::RectangleInfo& >())
        .def("width", (void (Magick::Geometry::*)(unsigned int) )&Magick::Geometry::width)
        .def("width", (unsigned int (Magick::Geometry::*)() const)&Magick::Geometry::width)
        .def("height", (void (Magick::Geometry::*)(unsigned int) )&Magick::Geometry::height)
        .def("height", (unsigned int (Magick::Geometry::*)() const)&Magick::Geometry::height)
        .def("xOff", (void (Magick::Geometry::*)(unsigned int) )&Magick::Geometry::xOff)
        .def("xOff", (unsigned int (Magick::Geometry::*)() const)&Magick::Geometry::xOff)
        .def("yOff", (void (Magick::Geometry::*)(unsigned int) )&Magick::Geometry::yOff)
        .def("yOff", (unsigned int (Magick::Geometry::*)() const)&Magick::Geometry::yOff)
        .def("xNegative", (void (Magick::Geometry::*)(bool) )&Magick::Geometry::xNegative)
        .def("xNegative", (bool (Magick::Geometry::*)() const)&Magick::Geometry::xNegative)
        .def("yNegative", (void (Magick::Geometry::*)(bool) )&Magick::Geometry::yNegative)
        .def("yNegative", (bool (Magick::Geometry::*)() const)&Magick::Geometry::yNegative)
        .def("percent", (void (Magick::Geometry::*)(bool) )&Magick::Geometry::percent)
        .def("percent", (bool (Magick::Geometry::*)() const)&Magick::Geometry::percent)
        .def("aspect", (void (Magick::Geometry::*)(bool) )&Magick::Geometry::aspect)
        .def("aspect", (bool (Magick::Geometry::*)() const)&Magick::Geometry::aspect)
        .def("greater", (void (Magick::Geometry::*)(bool) )&Magick::Geometry::greater)
        .def("greater", (bool (Magick::Geometry::*)() const)&Magick::Geometry::greater)
        .def("less", (void (Magick::Geometry::*)(bool) )&Magick::Geometry::less)
        .def("less", (bool (Magick::Geometry::*)() const)&Magick::Geometry::less)
        .def("isValid", (void (Magick::Geometry::*)(bool) )&Magick::Geometry::isValid)
        .def("isValid", (bool (Magick::Geometry::*)() const)&Magick::Geometry::isValid)
        .def( self <= self )
        .def( self == self )
        .def( self > self )
        .def( self != self )
        .def( self < self )
        .def( self >= self )
        .def("to_std_string", &Magick::Geometry::operator std::string)
        .def("to_MagickLib_RectangleInfo", &Magick::Geometry::operator MagickLib::RectangleInfo)
    ;

implicitly_convertible<std::string,Magick::Geometry>();}

==> pythonmagick_0.9.1.orig.tar.gz: PythonMagick-0.9.1/pythonmagick_src/_Geometry.cpp <==

// Boost Includes ==============================================================
#include <boost/python.hpp>
#include <boost/cstdint.hpp>

// Includes ====================================================================
#include <Magick++/Geometry.h>

// Using =======================================================================
using namespace boost::python;

// Module ======================================================================
void Export_pyste_src_Geometry()
{
    class_< Magick::Geometry >("Geometry", init<  >())
        .def(init< unsigned int, unsigned int, optional< unsigned int, unsigned int, bool, bool > >())
        .def(init< const std::string& >())
        .def(init< const char* >())
        .def(init< const Magick::Geometry& >())
        .def(init< const MagickCore::RectangleInfo& >())
        .def("width", (void (Magick::Geometry::*)(unsigned int) )&Magick::Geometry::width)
        .def("width", (unsigned int (Magick::Geometry::*)() const)&Magick::Geometry::width)
        .def("height", (void (Magick::Geometry::*)(unsigned int) )&Magick::Geometry::height)
        .def("height", (unsigned int (Magick::Geometry::*)() const)&Magick::Geometry::height)
        .def("xOff", (void (Magick::Geometry::*)(unsigned int) )&Magick::Geometry::xOff)
        .def("xOff", (unsigned int (Magick::Geometry::*)() const)&Magick::Geometry::xOff)
        .def("yOff", (void (Magick::Geometry::*)(unsigned int) )&Magick::Geometry::yOff)
        .def("yOff", (unsigned int (Magick::Geometry::*)() const)&Magick::Geometry::yOff)
        .def("xNegative", (void (Magick::Geometry::*)(bool) )&Magick::Geometry::xNegative)
        .def("xNegative", (bool (Magick::Geometry::*)() const)&Magick::Geometry::xNegative)
        .def("yNegative", (void (Magick::Geometry::*)(bool) )&Magick::Geometry::yNegative)
        .def("yNegative", (bool (Magick::Geometry::*)() const)&Magick::Geometry::yNegative)
        .def("percent", (void (Magick::Geometry::*)(bool) )&Magick::Geometry::percent)
        .def("percent", (bool (Magick::Geometry::*)() const)&Magick::Geometry::percent)
        .def("aspect", (void (Magick::Geometry::*)(bool) )&Magick::Geometry::aspect)
        .def("aspect", (bool (Magick::Geometry::*)() const)&Magick::Geometry::aspect)
        .def("greater", (void (Magick::Geometry::*)(bool) )&Magick::Geometry::greater)
        .def("greater", (bool (Magick::Geometry::*)() const)&Magick::Geometry::greater)
        .def("less", (void (Magick::Geometry::*)(bool) )&Magick::Geometry::less)
        .def("less", (bool (Magick::Geometry::*)() const)&Magick::Geometry::less)
        .def("isValid", (void (Magick::Geometry::*)(bool) )&Magick::Geometry::isValid)
        .def("isValid", (bool (Magick::Geometry::*)() const)&Magick::Geometry::isValid)
        .def( self <= self )
        .def( self == self )
        .def( self > self )
        .def( self != self )
        .def( self < self )
        .def( self >= self )
        .def("to_std_string", &Magick::Geometry::operator std::string)
        .def("to_MagickCore_RectangleInfo", &Magick::Geometry::operator MagickCore::RectangleInfo)
    ;

implicitly_convertible<std::string,Magick::Geometry>();}
